@@ -1,7 +1,8 @@
 import logging
+import os
 import re
 from pathlib import Path
-from typing import List
+from typing import Any, List
 
 from ..cli_common import CommonCLI
 from ..helpers.bootstrap import _install_py_reqs_by_odoo_cmd
@@ -13,6 +14,11 @@ CLI = CommonCLI()
 LOGGER = logging.getLogger(__name__)
 
 
+def _add_default_argument(cmd_list: List[str], arg: str, arg_val: Any):
+    if not any([arg in s for s in cmd_list]):
+        cmd_list.append(f'{arg}="{arg_val}"')
+
+
 def _boostrap_command(
     odoo_main_path: Path,
     odoo_conf_path: Path,
@@ -27,7 +33,7 @@ def _boostrap_command(
     extra_cmd_args: List[str] = None,
     install_base: bool = True,
     install_workspace_modules: bool = True,
-    multithread_worker_count: int = 9,
+    multithread_worker_count: int = -1,
     languages: str = "de_DE,en_US",
 ) -> str:
     """
@@ -104,16 +110,18 @@ def _boostrap_command(
         f"--config {str(odoo_conf_path.absolute())}",
         "--save",
         f"--load-language {languages}",
-        "--log-level info",
-        "--limit-time-cpu 360",
-        "--limit-time-real 420",
-        "--data-dir /var/lib/odoo",
         "--stop-after-init",
         f"--addons-path '{addon_paths}'",
     ]
     odoo_cmd = base_cmds + db_command
     if extra_cmd_args:
-        odoo_cmd.append(" ".join(extra_cmd_args))
+        odoo_cmd += extra_cmd_args
+
+    _add_default_argument(cmd_list=odoo_cmd, arg="--data-dir", arg_val="/var/lib/odoo")
+
+    if multithread_worker_count == -1:
+        multithread_worker_count = os.cpu_count() or 0 + 1
+
     if multithread_worker_count > 0:
         odoo_cmd += [
             "--proxy-mode",
@@ -131,7 +139,6 @@ def bootstrap_odoo(
     workspace_addon_path=CLI.odoo_paths.workspace_addon_path,
     thirdparty_addon_path=CLI.odoo_paths.thirdparty_addon_path,
     odoo_conf_path=CLI.odoo_paths.conf_path,
-    bootstrap_flag_location=CLI.odoo_paths.bootstrap_flag_location,
     db_filter=CLI.database.db_filter,
     db_host=CLI.database.db_host,
     db_port=CLI.database.db_port,
@@ -175,8 +182,6 @@ def bootstrap_odoo(
 
     LOGGER.info("Launching Bootstrap Commandline")
     ret = run_cmd(cmd_string).returncode
-    if ret == 0:
-        bootstrap_flag_location.touch()
-    else:
+    if ret != 0:
         LOGGER.error("Odoo-Bin Returned %d", ret)
     return CLI.returner(ret)
