@@ -1,4 +1,5 @@
 import logging
+import re
 import threading
 from pathlib import Path
 from typing import List
@@ -10,6 +11,7 @@ from ..helpers.odoo_files import get_odoo_module_paths, odoo_bin_get_version
 from ..helpers.system import run_cmd
 from .bootstrap import bootstrap_odoo
 from .rpc import import_to_odoo
+from .source_get import py_depends_by_db, update_odoo_conf
 
 CLI = CommonCLI()
 
@@ -55,7 +57,6 @@ def _launch_command(
 def pre_launch(
     odoo_main_path: Path,
     workspace_addon_path: Path,
-    bootstrap_flag_location: Path,
     thirdparty_addon_path: Path,
     odoo_conf_path: Path,
     db_filter: str,
@@ -74,7 +75,7 @@ def pre_launch(
     install_base: bool = True,
     launch_or_bootstrap: bool = False,
 ):
-    """Start Bootstrap if no bootstrap flag is found. And return Launch CMD.
+    """Start Bootstrap if no config file is found. And return Launch CMD.
 
     Parameters
     ----------
@@ -82,8 +83,6 @@ def pre_launch(
         Path to Odoo-bin folder
     workspace_addon_path : Path
         Path to workspace addons
-    bootstrap_flag_location : Path
-        path to bootstrap flag
     thirdparty_addon_path : Path
         path to thirdparty addons folder
     odoo_conf_path : Path
@@ -131,9 +130,10 @@ def pre_launch(
         log_file_path.unlink(missing_ok=True)
         extra_odoo_args.append("--logfile " + str(log_file_path.absolute()))
 
-    bootstraped = bootstrap_flag_location.exists()
+    bootstraped = odoo_conf_path.exists()
     LOGGER.info("Bootstrap Flag Status: %s", bootstraped)
     ret = ""
+    did_bootstrap = False
     if not bootstraped:
         _extra_bootstrap_args = extra_odoo_args.copy()
         if ea := extra_bootstrap_args:
@@ -149,7 +149,6 @@ def pre_launch(
             db_password=db_password,
             db_host=db_host,
             db_port=db_port,
-            bootstrap_flag_location=bootstrap_flag_location,
             thirdparty_addon_path=thirdparty_addon_path,
             odoo_main_path=odoo_main_path,
             odoo_conf_path=odoo_conf_path,
@@ -158,10 +157,12 @@ def pre_launch(
             no_install_workspace_modules=not install_workspace_addons,
             multithread_worker_count=multithread_worker_count,
         )
-        install_workspace_addons = True
         bootstraped = ret == 0
         if not bootstraped:
             return ret
+        did_bootstrap = True
+        if install_workspace_addons and bootstraped:
+            install_workspace_addons = False
 
         if launch_or_bootstrap:
             return
@@ -172,17 +173,38 @@ def pre_launch(
     odoo_main_path = odoo_main_path
     odoo_version = odoo_bin_get_version(odoo_main_path)
 
+    update_odoo_conf(
+        odoo_conf=odoo_conf_path,
+        odoo_main_path=odoo_main_path,
+        workspace_addon_path=workspace_addon_path,
+        thirdparty_addon_path=thirdparty_addon_path,
+    )
+    if not did_bootstrap:
+        py_depends_by_db(
+            odoo_main_path=odoo_main_path,
+            workspace_addon_path=workspace_addon_path,
+            thirdparty_addon_path=thirdparty_addon_path,
+            db_host=db_host,
+            db_port=db_port,
+            db_name=db_name,
+            db_user=db_user,
+            db_password=db_password,
+        )
+
     if dev_mode:
         extra_odoo_args.append("--dev xml,qweb,reload")
         if "16.0" in odoo_version:
             extra_odoo_args[-1] += ",werkzeug"
 
+    if multithread_worker_count == 0:
+        extra_odoo_args.append("--workers 0")
+
     return _launch_command(
         odoo_path=odoo_main_path,
         odoo_conf_path=odoo_conf_path,
         extra_cmd_args=extra_odoo_args,
         workspace_addon_path=workspace_addon_path,
-        upgrade_workspace_modules=not install_workspace_addons,
+        upgrade_workspace_modules=install_workspace_addons,
     )
 
 
@@ -191,7 +213,6 @@ def pre_launch(
 def launch_odoo(
     odoo_main_path=CLI.odoo_paths.bin_path,
     workspace_addon_path=CLI.odoo_paths.workspace_addon_path,
-    bootstrap_flag_location=CLI.odoo_paths.bootstrap_flag_location,
     thirdparty_addon_path=CLI.odoo_paths.thirdparty_addon_path,
     odoo_conf_path=CLI.odoo_paths.conf_path,
     db_filter=CLI.database.db_filter,
@@ -216,7 +237,6 @@ def launch_odoo(
     launch_cmd = pre_launch(
         odoo_main_path=odoo_main_path,
         workspace_addon_path=workspace_addon_path,
-        bootstrap_flag_location=bootstrap_flag_location,
         thirdparty_addon_path=thirdparty_addon_path,
         odoo_conf_path=odoo_conf_path,
         db_filter=db_filter,
@@ -251,7 +271,6 @@ def launch_import(
     ),
     odoo_main_path=CLI.odoo_paths.bin_path,
     workspace_addon_path=CLI.odoo_paths.workspace_addon_path,
-    bootstrap_flag_location=CLI.odoo_paths.bootstrap_flag_location,
     thirdparty_addon_path=CLI.odoo_paths.thirdparty_addon_path,
     odoo_conf_path=CLI.odoo_paths.conf_path,
     db_filter=CLI.database.db_filter,
@@ -277,7 +296,6 @@ def launch_import(
     launch_cmd = pre_launch(
         odoo_main_path=odoo_main_path,
         workspace_addon_path=workspace_addon_path,
-        bootstrap_flag_location=bootstrap_flag_location,
         thirdparty_addon_path=thirdparty_addon_path,
         odoo_conf_path=odoo_conf_path,
         db_filter=db_filter,
@@ -300,7 +318,7 @@ def launch_import(
         LOGGER.error("godoo Launch Failed. Bootstrap unsuccessfull. Aborting Launch...")
         return CLI.returner(launch_cmd)
 
-    launch_cmd = launch_cmd.replace(",reload ", " ")  # Remove reload option from CMD String
+    launch_cmd = re.sub(r"(--dev [\w,]+)(,reload)", r"\1", launch_cmd)  # Remove reload option from CMD String
 
     LOGGER.info("Starting Data Importer Thread for: '%s'", ", ".join(map(str, load_data_path)))
     loader_thread = threading.Thread(
