@@ -1,7 +1,8 @@
 import typer
 
+from .config_parameters import set_config_parameter
 from .importer import import_to_odoo
-from .modules import install_modules
+from .modules import install_modules, uninstall_modules
 from .translations import dump_translations
 
 
@@ -12,6 +13,7 @@ def modules_cli_app():
     )
 
     app.command(name="install")(install_modules)
+    app.command(name="uninstall")(uninstall_modules)
     app.command(name="dump-translation")(dump_translations)
     return app
 
@@ -26,6 +28,7 @@ def rpc_cli_app():
         typer_instance=modules_cli_app(),
         name="modules",
     )
+    app.command(name="set-config-param")(set_config_parameter)
     app.command("import")(import_to_odoo)
 
     return app
