@@ -46,9 +46,9 @@ def odoo_test(
     ),
     odoo_main_path=CLI.odoo_paths.bin_path,
     workspace_addon_path=CLI.odoo_paths.workspace_addon_path,
-    bootstrap_flag_location=CLI.odoo_paths.bootstrap_flag_location,
     thirdparty_addon_path=CLI.odoo_paths.thirdparty_addon_path,
     odoo_conf_path=CLI.odoo_paths.conf_path,
+    extra_launch_args=CLI.odoo_launch.extra_cmd_args,
     db_filter=CLI.database.db_filter,
     db_host=CLI.database.db_host,
     db_port=CLI.database.db_port,
@@ -96,12 +96,14 @@ def odoo_test(
         f"--test-tags {test_module_list}",
     ]
 
+    if extra_launch_args:
+        launch_args = extra_launch_args + launch_args
+
     launch_cmd = pre_launch(
         odoo_main_path=odoo_main_path,
         workspace_addon_path=workspace_addon_path,
         thirdparty_addon_path=thirdparty_addon_path,
         odoo_conf_path=odoo_conf_path,
-        bootstrap_flag_location=bootstrap_flag_location,
         db_filter=db_filter,
         db_host=db_host,
         db_port=db_port,
